package org.dromara.ems.base.service;

import org.dromara.ems.base.domain.EmsBaseMonitorThreshold;

import java.util.List;

/**
 * 计量设备阈值维护Service接口
 *
 * @author Yinq
 * @date 2024-07-09
 */
public interface IEmsBaseMonitorThresholdService {
    /**
     * 查询计量设备阈值维护
     *
     * @param objId 计量设备阈值维护主键
     * @return 计量设备阈值维护
     */
    public EmsBaseMonitorThreshold selectEmsBaseMonitorThresholdByObjId(Long objId);

    /**
     * 查询计量设备阈值维护列表
     *
     * @param emsBaseMonitorThreshold 计量设备阈值维护
     * @return 计量设备阈值维护集合
     */
    public List<EmsBaseMonitorThreshold> selectEmsBaseMonitorThresholdList(EmsBaseMonitorThreshold emsBaseMonitorThreshold);

    /**
     * 新增计量设备阈值维护
     *
     * @param emsBaseMonitorThreshold 计量设备阈值维护
     * @return 结果
     */
    public int insertEmsBaseMonitorThreshold(EmsBaseMonitorThreshold emsBaseMonitorThreshold);

    /**
     * 修改计量设备阈值维护
     *
     * @param emsBaseMonitorThreshold 计量设备阈值维护
     * @return 结果
     */
    public int updateEmsBaseMonitorThreshold(EmsBaseMonitorThreshold emsBaseMonitorThreshold);

    /**
     * 批量删除计量设备阈值维护
     *
     * @param objIds 需要删除的计量设备阈值维护主键集合
     * @return 结果
     */
    public int deleteEmsBaseMonitorThresholdByObjIds(Long[] objIds);

    /**
     * 删除计量设备阈值维护信息
     *
     * @param objId 计量设备阈值维护主键
     * @return 结果
     */
    public int deleteEmsBaseMonitorThresholdByObjId(Long objId);
}
